__name__ = 'ritetag'
__description__ = 'RiteTag API client.'
__url__ = 'https://github.com/pavelhouzva/ritetag-api-python'
__version__ = '1.3.0'
__author__ = 'Pavel Houžva'
__email__ = 'pavel@ritekit.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2021 Pavel Houžva'